@@ -29,9 +29,14 @@ __all__ = [
         "SUPPORT_PYDANTIC",
         "ASC", "DESC",
         "quick_load_client",
-        "get_config",
+        "get_config"
         ]
 
+from ._version import (
+            __version_info__,
+            __version__,
+            )
+
 from . import (
             main,
             aio,
